/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.admin.rest.resource.v1_0.util;

import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.LocaleUtil;
import com.liferay.portal.kernel.util.StringUtil;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

/**
 * @author Feliphe Marinho
 */
public class NameMapUtil {

	public static <K, V> Map<K, V> copy(
		Map<? extends K, ? extends V> sourceNameMap) {

		Map<K, V> targetNameMap = new HashMap<>();

		for (Map.Entry<? extends K, ? extends V> entry :
				sourceNameMap.entrySet()) {

			Locale locale = null;

			if (entry.getKey() instanceof Locale) {
				locale = (Locale)entry.getKey();
			}
			else {
				locale = LocaleUtil.fromLanguageId((String)entry.getKey());
			}

			targetNameMap.put(
				(K)entry.getKey(),
				(V)StringUtil.appendParentheticalSuffix(
					(String)entry.getValue(),
					LanguageUtil.get(locale, "copy")));
		}

		return targetNameMap;
	}

}